TUpdateWebhookEndpointBody class

Constructors

TUpdateWebhookEndpointBody({String? timestampMs, String? organizationId, required String endpointId, String? url, String? name, bool? isActive})
const
TUpdateWebhookEndpointBody.fromJson(Map<String, dynamic> json)
factory

Properties

endpointId String
Unique identifier of the webhook endpoint to update.
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool?
Updated active status.
final
name String?
Updated human-readable name.
final
organizationId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampMs String?
final
url String?
Updated destination URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited