externalactivityv1PolicyEvaluation class

Constructors

externalactivityv1PolicyEvaluation({required String id, required String activityId, required String organizationId, required String voteId, required List<immutablecommonv1PolicyEvaluation> policyEvaluations, required String createdAt})
const
externalactivityv1PolicyEvaluation.fromJson(Map<String, dynamic> json)
factory

Properties

activityId String
Unique identifier for a given Activity.
final
createdAt String
An ISO 8601 timestamp indicating when the PolicyEvaluation was created.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for a given policy evaluation.
final
organizationId String
Unique identifier for the Organization the Activity belongs to.
final
policyEvaluations List<immutablecommonv1PolicyEvaluation>
Detailed evaluation result for each Policy that was run.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voteId String
Unique identifier for the Vote associated with this policy evaluation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited