menu
zeroxkey_http package
documentation
__generated__/models.dart
rpcStatus class
rpcStatus class
dark_mode
light_mode
rpcStatus
class
Constructors
rpcStatus
({
num
?
code
,
String
?
message
,
List
<
protobufAny
>
?
details
})
const
rpcStatus.fromJson
(
Map
<
String
,
dynamic
>
json
)
factory
Properties
code
→
num
?
The status code, which should be an enum value of
google.rpc.Code
.
final
details
→
List
<
protobufAny
>
?
A list of messages that carry the error details. There is a common set of message types for APIs to use.
final
hashCode
→
int
The hash code for this object.
no setter
inherited
message
→
String
?
A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the
google.rpc.Status.details
field, or localized by the client.
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
zeroxkey_http package
documentation
__generated__/models
rpcStatus class
models library