details property

List<protobufAny>? details
final

A list of messages that carry the error details. There is a common set of message types for APIs to use.

Implementation

final List<protobufAny>? details;