webhookEndpoint property
The created webhook endpoint data, including the signing public key.
Implementation
final v1WebhookEndpointData webhookEndpoint;
The created webhook endpoint data, including the signing public key.
final v1WebhookEndpointData webhookEndpoint;