v1EmailVerifyInitRequest class

Constructors

v1EmailVerifyInitRequest({required String email, required String mode})
const
v1EmailVerifyInitRequest.fromJson(Map<String, dynamic> json)
factory

Properties

email String
Email address to verify.
final
hashCode int
The hash code for this object.
no setterinherited
mode String
Verification mode: 'signup' or 'login'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited