v1EmailVerifyInitResponse class

Constructors

v1EmailVerifyInitResponse({bool? sent, String? mode})
const
v1EmailVerifyInitResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mode String?
Actual mode used: may differ from requested mode if account already exists.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sent bool?
Whether the verification email was sent.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited