encryptedApiKey property
The proxy signing key generated by the Notarizer (dev: plaintext hex, prod: HPKE-encrypted).
Implementation
final String encryptedApiKey;
The proxy signing key generated by the Notarizer (dev: plaintext hex, prod: HPKE-encrypted).
final String encryptedApiKey;