v1SimulatePolicyChainRequest class

Constructors

v1SimulatePolicyChainRequest({required String organizationId, required String activityType, String? parametersJson, String? initiatorUserId, List<String>? approverUserIds, List<v1SimulationPolicy>? extraPolicies, List<String>? excludePolicyIds})
const
v1SimulatePolicyChainRequest.fromJson(Map<String, dynamic> json)
factory

Properties

activityType String
Activity type to simulate (e.g. ACTIVITY_TYPE_SIGN_TRANSACTION_V2).
final
approverUserIds List<String>?
Declared approver user IDs (assumed to have voted Approved). The initiator is always counted.
final
excludePolicyIds List<String>?
Existing policy IDs to exclude from evaluation.
final
extraPolicies List<v1SimulationPolicy>?
Hypothetical policies appended to the organization's policy list.
final
hashCode int
The hash code for this object.
no setterinherited
initiatorUserId String?
Declared initiator user ID. Defaults to the authenticated user when empty.
final
organizationId String
Unique identifier for a given organization.
final
parametersJson String?
Activity intent parameters as a JSON object string. Defaults to '{}' when empty.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited