matchedPolicyId property
Policy that determined the decision. Empty for root quorum bypass, implicit allow, and implicit deny.
Implementation
final String? matchedPolicyId;
Policy that determined the decision. Empty for root quorum bypass, implicit allow, and implicit deny.
final String? matchedPolicyId;