v1SimulationPolicyEvalDetail class
Constructors
- v1SimulationPolicyEvalDetail({required String policyId, String? policyName, required v1Effect effect, required bool conditionMatched, bool? consensusMet, required v1SimulationPolicyResult result, bool? shortCircuited, String? error})
-
const
-
v1SimulationPolicyEvalDetail.fromJson(Map<
String, dynamic> json) -
factory
Properties
- conditionMatched → bool
-
final
- consensusMet → bool?
-
Absent when consensus was never evaluated (condition didn't match or errored).
final
- effect → v1Effect
-
final
- error → String?
-
Consensus CEL evaluation error message, if any.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- policyId → String
-
final
- policyName → String?
-
final
- result → v1SimulationPolicyResult
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortCircuited → bool?
-
True when this DENY stopped the chain — later policies were never evaluated.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited