v1SimulationPolicyResult enum

Inheritance
Available extensions

Values

simulation_policy_result_unspecified → const v1SimulationPolicyResult
simulation_policy_result_allow → const v1SimulationPolicyResult
simulation_policy_result_deny_explicit → const v1SimulationPolicyResult
simulation_policy_result_requires_consensus → const v1SimulationPolicyResult
simulation_policy_result_not_applicable → const v1SimulationPolicyResult
simulation_policy_result_error → const v1SimulationPolicyResult

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<v1SimulationPolicyResult>
A constant List of the values in this enum, in order of their declaration.