v1WebhookSubscriptionParams class

Constructors

v1WebhookSubscriptionParams({required String eventType, String? filtersJson, bool? isActive})
const
v1WebhookSubscriptionParams.fromJson(Map<String, dynamic> json)
factory

Properties

eventType String
The event type to subscribe to, e.g. ACTIVITY_UPDATES, BALANCE_CONFIRMED_UPDATES.
final
filtersJson String?
JSON-encoded filter criteria for this subscription. Reserved for future use.
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool?
Whether this subscription is active. Defaults to true.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited