v1TokenUsage class

Constructors

v1TokenUsage({required v1UsageType type, required String tokenId, v1SignupUsageV2? signupV2, v1LoginUsage? login})
const
v1TokenUsage.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
login v1LoginUsage?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signupV2 v1SignupUsageV2?
final
tokenId String
final
type v1UsageType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited