base library

Classes

DefaultHttpTransport
Default HttpTransport backed by package:http.
GrpcStatus
HttpResponse
Minimal, transport-agnostic representation of an HTTP response.
HttpTransport
Abstraction over the network layer used by ZeroXKeyClient.
THttpConfig
TSignedRequest
Represents a signed request ready to be POSTed to ZeroXKey
TStamp
Represents a stamp header name/value pair attached to a signed request.
TStamper
Interface for request stampers used by ZeroXKeyClient and stamper packages.

Functions

sealAndStampRequestBody({required Map<String, dynamic> body, String? apiPublicKey, String? apiPrivateKey}) Future<Map<String, String>>
Seals and stamps the request body with your ZeroXKey API credentials.
stableStringify(Map<String, dynamic> input) String
Converts a Map<String, dynamic> into a JSON string representation.

Exceptions / Errors

ZeroXKeyRequestError
Interface to implement if you want to provide your own stampers for your ZeroXKeyClient.