v1EmailVerifyRedirectResponse class
Constructors
- v1EmailVerifyRedirectResponse({bool? verified, String? sessionToken, String? mode, String? email})
-
const
-
v1EmailVerifyRedirectResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- email → String?
-
Verified email address.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → String?
-
Original verification mode: 'signup' or 'login'.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionToken → String?
-
Session token for cookie.
final
- verified → bool?
-
Whether the email was verified.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited