v1SimulationPolicy class
Constructors
- v1SimulationPolicy({String? policyId, String? policyName, required v1Effect effect, String? condition, String? consensus})
-
const
-
v1SimulationPolicy.fromJson(Map<
String, dynamic> json) -
factory
Properties
- condition → String?
-
CEL condition expression.
final
- consensus → String?
-
CEL consensus expression.
final
- effect → v1Effect
-
ALLOW or DENY.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- policyId → String?
-
Identifier for the hypothetical policy (any unique string).
final
- policyName → String?
-
Human-readable name for the hypothetical policy.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited