v1ValidateSessionResponse class
Constructors
- v1ValidateSessionResponse({bool? valid, String? sessionType, String? email, String? organizationId, String? userId})
-
const
-
v1ValidateSessionResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- email → String?
-
Email associated with the session.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- organizationId → String?
-
Organization ID (may be empty for initial-registration before org creation).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionType → String?
-
Session type: 'initial-registration' or 'standard'.
final
- userId → String?
-
User ID (may be empty for initial-registration).
final
- valid → bool?
-
Whether the session is valid.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited