v1WebhookEndpointData class
Constructors
-
v1WebhookEndpointData({required String endpointId, required String organizationId, required String url, required String name, required bool isActive, List<
v1WebhookSubscriptionParams> ? subscriptions, String? signingPublicKey}) -
const
-
v1WebhookEndpointData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- endpointId → String
-
Unique identifier for a given Webhook Endpoint.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Whether the endpoint is currently active and receiving deliveries.
final
- name → String
-
Human-readable name for the webhook endpoint.
final
- organizationId → String
-
Unique identifier for the Organization that owns this endpoint.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signingPublicKey → String?
-
Ed25519 public key (whpk_ prefixed) for verifying webhook signatures. Only returned on creation.
final
-
subscriptions
→ List<
v1WebhookSubscriptionParams> ? -
Event subscriptions for this endpoint.
final
- url → String
-
The destination URL for webhook deliveries.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited