ZeroXKeyRequestError class

Interface to implement if you want to provide your own stampers for your ZeroXKeyClient.

Currently, ZeroXKey provides two stampers:

  • Applications signing requests with Passkeys or WebAuthn devices should use @zeroxkey/webauthn-stamper.
  • Applications signing requests with API keys should use @zeroxkey/api-key-stamper.
Implemented types

Constructors

ZeroXKeyRequestError(GrpcStatus status)

Properties

code int
final
details List?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited